@@ -5,9 +5,9 @@
 #
 # Copyright 2013, John McNamara, jmcnamara@cpan.org
 #
-from xlsxwriter.workbook import Workbook
+import xlsxwriter
 
-workbook = Workbook('tab_colors.xlsx')
+workbook = xlsxwriter.Workbook('tab_colors.xlsx')
 
 # Set up some worksheets.
 worksheet1 = workbook.add_worksheet()
